#
# spec file for package netlabel
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           netlabel
%define         upstream_version 0.20
%define         netlabel_docdir %{_docdir}/%{name}
%if 0%{?suse_version} >= 1210
%bcond_without  systemd
%else
%bcond_with     systemd
%endif
Version:        0.20
Release:        10.1
Summary:        Explicit labeled networking for Linux
License:        GPL-2.0
Group:          Productivity/Networking/Security
Url:            http://netlabel.sourceforge.net/
Source0:        http://downloads.sourceforge.net/project/netlabel/netlabel_tools/%{upstream_version}/netlabel_tools-%{upstream_version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  doxygen
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libnl-3.0)
# PATCH-FIX-UPSTREAM netlabel_tools-0.20.diff mt@suse.de
Patch0:         netlabel_tools-0.20.diff
# PATCH-FIX-OPENSUSE netlabel_tools-0.20-service.diff mt@suse.de
Patch1:         netlabel_tools-0.20-service.diff
#PATCH-FIX_OPENSUSE posted to upstream late may 2014, port to libnl3
Patch2:         0001-Port-to-libnl3.patch

%description
Explicit labeled networking for Linux

The NetLabel control utility, netlabelctl, is a command line program designed
to allow system administrators to configure the NetLabel system in the kernel.
The utility is based around different "modules" which correspond to the
different types of NetLabel commands supported by the kernel.

%package tools
Summary:        Control utility for explicit labeled networking for Linux
Group:          Productivity/Networking/Security

%description tools
Explicit labeled networking for Linux

The NetLabel control utility, netlabelctl, is a command line program designed
to allow system administrators to configure the NetLabel system in the kernel.
The utility is based around different "modules" which correspond to the
different types of NetLabel commands supported by the kernel.

#
# Note: there's no NetLabel Daemon implemented yet,
#       the libraries are not installed by default.
#
%prep
%setup -q -n netlabel_tools-%{upstream_version}
%patch0 -p0
%patch1 -p0
%patch2 -p1
%build
CFLAGS="$RPM_OPT_FLAGS -W -Wall"
export RPM_OPT_FLAGS CFLAGS
%configure \
%if %{with systemd}
	--enable-systemd \
%endif
	--prefix=%{_prefix} --libdir=%{_libdir} 
%__make V=1 clean
%__make V=1

%install
export RPM_BUILD_ROOT
make install V=1 DESTDIR="$RPM_BUILD_ROOT"
%if %{with systemd}
install -d -m 0755  "$RPM_BUILD_ROOT%{_sbindir}"
ln -s %{_sbindir}/service "$RPM_BUILD_ROOT%{_sbindir}/rcnetlabel"
%endif

%pre
%{service_add_pre netlabel.service}

%post
%if %{with systemd}
%{service_del_preun netlabel.service}
%endif

%preun
%if %{with systemd}
%{service_del_preun netlabel.service}
%endif

%postun
%if %{with systemd}
%{service_del_postun netlabel.service}
%endif

%files tools
%defattr(-,root,root)
%config(noreplace) %attr(600,root,root) %{_sysconfdir}/netlabel.rules
%{_sbindir}/netlabelctl
%{_sbindir}/netlabel-config
%if %{with systemd}
%{_sbindir}/rcnetlabel
%{_unitdir}/netlabel.service
%endif
%doc LICENSE README CHANGELOG
%{_mandir}/man8/netlabelctl.8.gz
%{_mandir}/man8/netlabel-config.8.gz

%changelog
* Thu Mar  5 2015 p.drouand@gmail.com
- Remove dependency on fillup and insserv; the packages provides neither
  sysconfig script nor sysvinit script
- Remove depreciated AUTHORS section
* Mon Jun  2 2014 crrodriguez@opensuse.org
- Port to libnl3 (0001-Port-to-libnl3.patch)
  This is the last package depending on libnl1, after all
  relevant requests are accepted, libnl1 can be dropped.
* Wed Mar 26 2014 mt@suse.de
- Install LICENSE, README, CHANGELOG as documentation
* Wed Mar 26 2014 mt@suse.de
- Update to netlabel tools 0.20 providing the following fixes:
  - Patch from Marius Tomaschewski <mt@suse.de> to fix the
    Makefile install target to allow installation by normal users
  - Fixed build problems on Debian/Ubuntu
  - Correctly read all the parts of multipart Netlink messages,
    fixed problems when trying to display large configurations
  - Updated the doxygen configuration file to work with modern
    doxygen versions
  - Updated and improved portions of the build mechanism
  - Incorporate fixes from the Fedora/RHEL RPMs
  - Add support for systemd with the inclusion of a systemd unit
    file, configuration file, and configuration helper script
- Fixed install rules to allow installation as normal users (again),
  corrected link option order for as-needed, adjusted service file,
  replacing netlabel_tools-0.19.diff by netlabel_tools-0.20.diff
  and adding netlabel_tools-0.20-service.diff patches.
- Removed unneeded netlabel_tools-0.19-version_info.diff patch
* Sat Feb 23 2013 andreas.stieger@gmx.de
- fix Makefile to find version_info file in openSUSE 12.3 and up,
  adding netlabel_tools-0.19-version_info.diff
* Wed May 16 2012 andreas.stieger@gmx.de
- Explicitly require libnl-1_1-devel for openSUSE 12.1 and up
  to fix build
* Wed Sep 30 2009 mt@suse.de
- Initial netlabel-tools package (fate#307618)
